#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.4
visibility:           public
id:                   wreq-0.5.4.4-9jKMZMCZAuVGAiiasSV4XS
key:                  wreq-0.5.4.4-9jKMZMCZAuVGAiiasSV4XS
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           Ondřej Palkovský
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  1f5c066248f9169b316997526253ed57
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.4-9jKMZMCZAuVGAiiasSV4XS
depends:
    aeson-2.2.1.0-FEnGzvKMunxDwDFhBeJYHO
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx
    authenticate-oauth-1.7-GyvkJ3kTGoy4NIoAueL2XH base-4.18.2.1
    base16-bytestring-1.0.2.0-BrKum4UJoGp9BOvJ2feb26
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-DkQB71KJg2v82iYJB6vXcb
    containers-0.6.7 crypton-1.0.4-I0bzTn2woJ4DLB7BtNhDWv
    exceptions-0.10.7 hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    http-client-0.7.19-KIsPCwAmJfj40FXZ7rXqbo
    http-client-tls-0.3.6.4-Doual9R7PJYKTahqZ4qgD9
    http-types-0.12.4-5BZtRmLQcWTCOOFKM75zCu
    lens-5.3.4-B9QPRzrMZ8J355CXfNFvnN
    lens-aeson-1.2.3-BuOIc68lGpD152h2I1wgKQ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN
    psqueues-0.2.8.3-GW2k897xYkj5kjciVeDVMF template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

